Asphalt-mailer documentation
============================

Asphalt-mailer provides :class:`~asphalt.mailer.api.Mailer` resources that enable other components
to send email messages. Two backends (``smtp`` and ``sendmail``) are provided, but other projects
may provide additional backends.

.. toctree::
   :maxdepth: 2

   configuration
   usage
   testing
   extending
   versionhistory

Indices and tables
==================

* :ref:`API reference <modindex>`
